<!--
 * @Date: 2024-04-09 22:11:21
 * @LastEditors: lzhe lzhe@example.com
 * @LastEditTime: 2024-11-04 12:23:49
 * @FilePath: /belleson-frontend/Users/mache/Documents/demo/cps-web/src/views/mdc/efficiency-analysis.vue
 * 效率分析
-->
<template>
    <el-main style="height: 100%;" class="efficiencyAnalysis">
        <el-card shadow="never" style="height: 100%;" body-style="height: 100%">
            <el-container style="height: 100%;">
                <el-aside width="300px" style="height: 100%;">
                    <el-container>
                        <el-main class="nopadding">
                            <el-row>
                                <el-col>统计数据</el-col>
                                <el-col>
                                    <el-select style="width: 250px" v-model="productivityType">
                                        <el-option v-for="(item, index) in options" :key="index" :label="item.label"
                                            :value="item.value"></el-option>
                                    </el-select>
                                </el-col>
                                <el-col style="margin-top: 14px;">日期</el-col>
                                <el-col>
                                    <el-date-picker value-format="YYYY-MM-DD" style="width: 250px" v-model="time"
                                        type="daterange" range-separator="-" start-placeholder="" end-placeholder="" />
                                </el-col>
                            </el-row>
                            <el-row style="margin-top: 14px;">
                                工位
                            </el-row>
                            <MYTree v-model="treeChecked" show-checkbox></MYTree>
                        </el-main>
                        <el-footer>
                            <el-button type="primary" @click="query">查询</el-button>
                            <!-- <el-button @click="exportExcel">导出</el-button> -->
                            <exportDialog @export="exportExcel"></exportDialog>
                        </el-footer>
                    </el-container>
                </el-aside>
                <el-container>
                    <el-main style="position: relative;">
                        <span class="setSpan">
                            <el-icon class="setIcon">
                                <Setting />
                            </el-icon>
                            <span class="setBtn" @click="openSet">效率分析设置</span>
                        </span>
                        <el-tabs tab-position="top" v-model="activeName" type="card">
                            <el-tab-pane label="按班次统计" name="shift">
                                <Shift :options="chartOption" colname="效率" ref="shift" v-if="activeName == 'shift'" />
                            </el-tab-pane>
                            <el-tab-pane label="按时间周期统计" name="time">
                                <Time :options="chartOption1" ref="time" v-if="activeName == 'time'" />
                            </el-tab-pane>
                        </el-tabs>
                    </el-main>
                </el-container>
            </el-container>
        </el-card>
        <el-dialog title="设置" v-model="dialogVisible" v-if="dialogVisible" width="30%" class="setModelStyle">
            <Efficiency :showModalList="showModalList" />
        </el-dialog>
    </el-main>
</template>

<script>
import moment from 'moment';
import MYTree from './MYTree.vue'
import Shift from './components/Shift.vue'
import Time from './components/Time.vue'
import exportDialog from '@/layout/components/exportDialog.vue'
import Efficiency from './configComp/Efficiency.vue'
import * as ElementPlusIconsVue from '@element-plus/icons-vue'
let icons = []
for (const [key, component] of Object.entries(ElementPlusIconsVue)) {
    icons.push(key)
}
export default {
    components: {
        ...ElementPlusIconsVue,
        MYTree,
        Shift,
        Time,
        exportDialog,
        Efficiency
    },
    watch: {
        activeName() {
            this.$nextTick(() => {
                this.query()
            })

        }
    },
    data() {
        return {
            dialogVisible: false,
            showModalList: [2],
            activeName: 'shift',
            productivityType: 'OEE',
            time: [],
            treeChecked: [],
            chartOption1: {
                title: {
                    text: '统计图表',
                    subtext: '',
                },
                grid: {
                    top: '80px'
                },
                tooltip: {
                    trigger: 'axis'
                },
                tooltip: {
                    trigger: 'axis',
                    valueFormatter: (params) => {
                        return params.toFixed(2) + '%'
                    }
                },
                xAxis: {
                    type: 'category',
                    axisLabel: {
                        interval: 'auto',
                    }
                },
                yAxis: {
                    type: 'value',
                    axisLabel: {
                        formatter: (value) => {
                            return value + '%'
                        }
                    },
                },
                dataZoom: [
                    { type: 'slider' }
                ],
                dataset: {
                    source: []
                },
                series: []
            },
            chartOption: {
                legend: {
                    type: 'plain',
                },
                title: {
                    text: '统计图表',
                    subtext: '',
                },
                grid: {
                    top: '80px'
                },
                tooltip: {
                    trigger: 'axis',
                    valueFormatter: (params) => {
                        console.log(params, '>>>>>>>>.113213')
                        return params.toFixed(2) + '%'
                    }
                },
                xAxis: {
                    type: 'category',
                },
                yAxis: {
                    type: 'value',
                    axisLabel: {
                        formatter: (value) => {
                            return value + '%'
                        }
                    },
                },
                dataZoom: [
                    { type: 'slider' }
                ],
                dataset: {
                    source: [
                        ['product', '班次1', '班次2'],
                    ]
                },
                series: [
                    {
                        type: 'bar',
                    },
                    {
                        type: 'bar',
                    }
                ]
            },
            options: [
                {
                    label: '稼动率',
                    value: 'OEE',
                },
                {
                    label: '报警率',
                    value: 'ALARM',
                },
                {
                    label: '运行率',
                    value: 'RUNNING',
                },
            ]
        }
    },
    created() {
        this.time = [moment().format('YYYY-MM-DD'), moment().format('YYYY-MM-DD')]
    },
    mounted() {
        this.query()
    },
    methods: {
        openSet() {
            this.dialogVisible = true;
        },
        exportExcel(statisticalMethod) {
            this.$HTTP.post(`/api/mdc/efficiency-analysis/export`, {
                startDate: this.time[0],
                endDate: this.time[1],
                statisticalMethod,
                productivityType: this.productivityType,
                shiftIndexList: [1, 2],
                workStationIdList: this.treeChecked
            }).then(res => {
                if (res.success) {
                    window.open(res.data.link)
                } else {
                    this.$message.error(res.msg)
                }
            })
        },
        query() {
            this.$refs[this.activeName].init({
                endDate: this.time[1],
                startDate: this.time[0],
                productivityType: this.productivityType,
                shiftIndexList: [1, 2],
                workStationIdList: [...this.treeChecked]
            })
        }
    }
}
</script>

<style scoped>
    .setSpan {
        vertical-align: sub;
        font-size: 14px;
        position: absolute;
        top: 26px;
        left: 280px;
        z-index: 11;
    }
    .setIcon {
        color: #409eff;
        margin-left: 15px;
        vertical-align: -2px;
    }
    .setBtn {
        margin-left: 2px;
        color: #409eff;
        margin-left: 8px;
        cursor: pointer;
        font-size: 14px;
    }
    .efficiencyAnalysis >>> .el-dialog__body {
        padding-bottom: 0px;
        padding-top: 0px;
    }
</style>